# DeepTL_dev

### Version: 0.0.6_dev

0.0.1_dev update: integrate deeptl with anndata

0.0.2_dev update: support pyscenic regulons

0.0.3_dev update: support large scale data analysis

0.0.4_dev update: support random state

0.0.5_dev update: support trajectory draw graph

0.0.6_dev update: integrate scanpy pca









